==> dl.php?src=linea21_1_4.zip: linea21/languages/es/lang_home.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage es
 * @author Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['home']['name']="Inicio";
$lang['home']['project']="Proyectos con fecha estimada de finalización cercana";
$lang['home']['yp']="organización(es) actualmente en espera para registrarse";
$lang['home']['dashboard']="indicador(es) para actualizar";
$lang['home']['user']="usuario(s) registrados desde la última sesión";
$lang['home']['news']="Últimas 3 noticias";
$lang['home']['publi']="Última publicación";
$lang['home']['report']="Últimos informes publicados por los grupos de trabajo";
$lang['home']['accueil']="Bienvenido a la consola de administracion de Linea 21. Podrá acceder a distintos módulos, dependiendo de sus derechos como administrador. Para cualquier duda o comentario, por favor, contacte directamente con el soporte informático en esta dirección ";

$lang['home']['resume']="Gestor de tareas Linea21";
$lang['home']['noresult']="No existen valores publicados en este módulo";
$lang['home']['noupdate']="No existen valores actualizados en este módulo";
$lang['home']['help']=SITE_LINEA_NAME;
$lang['home']['help_list1']="Para acceder a un módulo haga click en su nombre, en el menú situado a la izquierda.";
$lang['home']['help_list2']="Puede realizar búsquedas utilizando el input del campo 'buscar'.";
$lang['home']['help_list3']="Para buscar dentro de un módulo, entre en el módulo y haga click en el 'buscar'.";
$lang['home']['help_list4']="No dude en utilizar las ayudas específicas de cada módulo.";


?>

==> dl.php?src=linea21_1_6.zip: linea21/languages/es/lang_home.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage es
 * @author Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['home']['name']="Inicio";
$lang['home']['comment']="Latest %s comments"; // @todo translation
$lang['home']['comment_to_moderate']="%s comments to moderate"; // @todo translation
$lang['home']['project']="Proyectos con fecha estimada de finalización cercana";
$lang['home']['workshop_pending_users']="workgroups : %s pending users"; // @todo translation
$lang['home']['yp']="organización(es) actualmente en espera para registrarse";
$lang['home']['dashboard']="indicador(es) para actualizar";
$lang['home']['user']="usuario(s) registrados desde la última sesión";
$lang['home']['news']="Últimas 3 noticias";
$lang['home']['publi']="Última publicación";
$lang['home']['report']="Últimos informes publicados por los grupos de trabajo";
$lang['home']['accueil']="Bienvenido a la consola de administracion de Linea 21. Podrá acceder a distintos módulos, dependiendo de sus derechos como administrador. Para cualquier duda o comentario, por favor, contacte directamente con el soporte informático en esta dirección ";

$lang['home']['resume']="Gestor de tareas Linea21";
$lang['home']['noresult']="No existen valores publicados en este módulo";
$lang['home']['noupdate']="No existen valores actualizados en este módulo";
$lang['home']['help']=SITE_LINEA_NAME;
$lang['home']['help_list1']="Para acceder a un módulo haga click en su nombre, en el menú situado a la izquierda.";
$lang['home']['help_list2']="Puede realizar búsquedas utilizando el input del campo 'buscar'.";
$lang['home']['help_list3']="Para buscar dentro de un módulo, entre en el módulo y haga click en el 'buscar'.";
$lang['home']['help_list4']="No dude en utilizar las ayudas específicas de cada módulo.";


?>
